@@ -10,14 +10,9 @@ import re
 
 
 from utils import welcome
-from utils import sign_up
-from utils import log_in
-from utils import close_app
-from utils import logged_in
-from utils import delete_User
 
 load_dotenv(dotenv_path='.env')
 
                 
 if __name__ == "__main__":
-   welcome()
+    welcome()
