@@ -9,9 +9,20 @@ import random
 import string
 import re
 
+load_dotenv(dotenv_path='.env')
 
 class welcome():
-    def __init__(self):
+    pusher = None
+    channel = None
+    chatroom = None
+    clientPusher = None
+    user = None
+    users=()
+   
+    chatrooms = ["Python", "Java", "php", "Javascript", "Stacks", "General"]
+
+    ''' The entry point of the application'''
+    def main(self):
         print("\n")     
         print(colored("        ---- DevGossip ----      ", "blue"))
         print(colored("*********************************", "blue"))
@@ -23,22 +34,20 @@ class welcome():
 
 
         if selection == str(1):
-            sign_up()
+            self.signup()
+            self.main()
         elif selection == str(2):
-            log_in()
+            self.login()
             while True:
-                logged_in()
+                self.logged()
         elif selection == str(3):
-            close_app()
+            self.closeApp()
         else:
             print("Please input '1' to signup; '2' to login or '3' to close the app")
-            welcome()
-
-            
+            self.main()
 
     ''' This function handles signup to the system'''
-class sign_up:
-    def __init__(self):
+    def signup(self):
         print("\n")
         print("Please pres Ctrl+c at anytime to cancel signup and go back to Welcome page")        
         try:
@@ -69,20 +78,17 @@ class sign_up:
                 for details in [userName, passWord, email_add]:
                     users.write(f"{details} ",)
                 users.write('\n')
-            welcome()
         
         except KeyboardInterrupt:
             print("Registration was cancelled.")
-            welcome()
+            self.main()
 
 
         
 
     ''' This function handles logon to the system'''
-class log_in:
-    users=()
 
-    def __init__(self):
+    def login(self):
         print("\n")
         print("Please pres Ctrl+c at anytime to cancel 'Login' and go back to Welcome page")        
         try:
@@ -104,26 +110,14 @@ class log_in:
 
         except KeyboardInterrupt:
             print("Login was terminated")
-            welcome()
-
-
+            self.main()
 
     '''To close the app'''
-class close_app:
-    def __init__(self):
+    def closeApp(self):
         exit()
 
-
-
-class logged_in:
-    pusher = None
-    channel = None
-    chatroom = None
-    clientPusher = None
-    user = None
     
-    chatrooms = ["Python", "Java", "C#", "C++", "Javascript", "New languages", "General"]
-    def __init__(self):
+    def logged(self):
         print("\n")        
         print(colored("You're logged in   ", "blue"))
         print(colored("<< 1. Logout                        >>", "yellow"))
@@ -135,16 +129,17 @@ class logged_in:
 
         if selection == str(1):
             print("You are logged out")
-            welcome()
+            self.main()
         elif selection == str(2):
             self.selectChatroom()
             while True:
                 self.getInput()
         elif selection == str(3):
-            delete_User()
+            self.del_users()
         else:
             print("Please input '1' to Logout; '2' to Choose a room or '3' to delete your account")
-            logged_in()
+            self.logged()
+
 
 
     ''' This function is used to select which chatroom you would like to connect to '''
@@ -153,6 +148,7 @@ class logged_in:
         print(colored("Info! Available Rooms are %s" % str(self.chatrooms), "blue"))
         chatroom = input(colored("Please select a Room: ", "green")).capitalize()
         if chatroom in self.chatrooms:
+            print("Please pres Ctrl+c at anytime to exit the Room")
             self.chatroom = chatroom
             self.initPusher()
         else:
@@ -181,17 +177,16 @@ class logged_in:
     
     ''' This function is used to get the user's current message '''
     def getInput(self):
-        print("Please pres Ctrl+c at anytime to exit the Room")        
         try:
             message = input(colored("{}: ".format(self.user), "green"))
             self.pusher.trigger(self.chatroom, u'newmessage', {"user": self.user, "message": message})
         except KeyboardInterrupt:
-            self.selectChatroom()
+            self.logged()
     
 
 
-class delete_User:
-    def __init__(self):
+    ''' This function is used to delete the user's account '''
+    def del_users(self):
         print("\n")
         print("Please pres Ctrl+c to terminate this process")   
         try:
@@ -206,8 +201,9 @@ class delete_User:
                             f.write(line)
                     f.truncate()
                 print("Your account has been deleted")
-                welcome()
+                self.main()
             elif yn == 'n':
-                logged_in()
+                self.logged()
         except KeyboardInterrupt:
-            logged_in()
+            self.logged()
+            
